@@ -6,7 +6,7 @@ from debutizer.errors import CommandError
 from debutizer.print_utils import print_color, print_error
 
 
-def main():
+def main() -> None:
     """An exception handling wrapper around the real entrypoint, _main"""
     try:
         _main()
@@ -22,13 +22,14 @@ def main():
             sys.exit(1)
 
 
-def _main():
+def _main() -> None:
     root = commands.RootCommand()
 
     root.add_subcommand("source", commands.SourceCommand())
     root.add_subcommand("build", commands.BuildCommand())
     root.add_subcommand("check", commands.CheckCommand())
     root.add_subcommand("upload", commands.UploadCommand())
+    root.add_subcommand("version", commands.VersionCommand())
 
     root.run()
 
