@@ -2,13 +2,16 @@ import os
 import platform
 from abc import ABC, abstractmethod
 from pathlib import Path
-from typing import Any, Dict, List, Optional, Type
+from typing import Any, Dict, List, Optional, Type, Union
 
 import yaml
 from xdg.BaseDirectory import save_config_path
 
 from debutizer.errors import CommandError
 
+_YAML_TYPES = Union[str, list, dict, int, bool, float]
+"""Python types that a YAML field can represent"""
+
 
 class DebutizerYAMLError(CommandError):
     """An error as a result of the contents of the debutizer.yaml"""
@@ -23,7 +26,7 @@ class _ConfigurationSection(ABC):
 
     @staticmethod
     @abstractmethod
-    def from_dict(config: Dict[str, Any]):
+    def from_dict(config: Dict[str, Any]) -> "_ConfigurationSection":
         ...
 
 
@@ -32,11 +35,11 @@ class UploadTargetConfiguration(_ConfigurationSection):
         self.type = type_
 
     @abstractmethod
-    def check_validity(self):
+    def check_validity(self) -> None:
         ...
 
 
-class S3Configuration(UploadTargetConfiguration):
+class S3UploadTargetConfiguration(UploadTargetConfiguration):
     TYPE = "s3"
 
     def __init__(
@@ -52,7 +55,7 @@ class S3Configuration(UploadTargetConfiguration):
         gpg_signing_key: Optional[str] = None,
         gpg_signing_password: Optional[str] = None,
     ):
-        super().__init__(S3Configuration.TYPE)
+        super().__init__(S3UploadTargetConfiguration.TYPE)
 
         if prefix is not None:
             # Normalize slashes in prefix
@@ -73,7 +76,7 @@ class S3Configuration(UploadTargetConfiguration):
         self.gpg_signing_password = gpg_signing_password
 
     @staticmethod
-    def from_dict(config: Dict[str, Any]) -> "S3Configuration":
+    def from_dict(config: Dict[str, Any]) -> "S3UploadTargetConfiguration":
         endpoint = _required(config, "endpoint", str)
         bucket = _required(config, "bucket", str)
         prefix = _optional(config, "prefix", str, None)
@@ -101,7 +104,7 @@ class S3Configuration(UploadTargetConfiguration):
         gpg_signing_key = os.environ.get("DEBUTIZER_GPG_SIGNING_KEY")
         gpg_signing_password = os.environ.get("DEBUTIZER_GPG_SIGNING_PASSWORD")
 
-        return S3Configuration(
+        return S3UploadTargetConfiguration(
             endpoint=endpoint,
             bucket=bucket,
             prefix=prefix,
@@ -114,7 +117,7 @@ class S3Configuration(UploadTargetConfiguration):
             gpg_signing_password=gpg_signing_password,
         )
 
-    def check_validity(self):
+    def check_validity(self) -> None:
         if self.access_key is None or self.secret_key is None:
             raise CredentialsYAMLError(
                 f"When using an S3-compatible bucket, an access key and secret key "
@@ -124,14 +127,13 @@ class S3Configuration(UploadTargetConfiguration):
                 f"{_credentials_file()} file"
             )
 
-        if self.sign and self.gpg_key_id is None and self.gpg_signing_key is None:
+        if self.sign and self.gpg_key_id is None:
             raise DebutizerYAMLError(
-                "When package signing is enabled, either the gpg_key_id field or "
-                "DEBUTIZER_GPG_SIGNING_KEY environment variable must be set"
+                "When package signing is enabled, the gpg_key_id field must be set"
             )
 
 
-class PPAConfiguration(UploadTargetConfiguration):
+class PPAUploadTargetConfiguration(UploadTargetConfiguration):
     TYPE = "ppa"
 
     def __init__(
@@ -143,7 +145,7 @@ class PPAConfiguration(UploadTargetConfiguration):
         gpg_signing_password: Optional[str] = None,
         force: Optional[bool] = False,
     ):
-        super().__init__(PPAConfiguration.TYPE)
+        super().__init__(PPAUploadTargetConfiguration.TYPE)
 
         self.repo = repo
         self.sign = sign
@@ -153,11 +155,11 @@ class PPAConfiguration(UploadTargetConfiguration):
         self.force = force
 
     @staticmethod
-    def from_dict(config: Dict[str, Any]) -> "PPAConfiguration":
+    def from_dict(config: Dict[str, Any]) -> "PPAUploadTargetConfiguration":
         gpg_signing_key = os.environ.get("DEBUTIZER_GPG_SIGNING_KEY")
         gpg_signing_password = os.environ.get("DEBUTIZER_GPG_SIGNING_PASSWORD")
 
-        return PPAConfiguration(
+        return PPAUploadTargetConfiguration(
             repo=_required(config, "repo", str),
             sign=_optional(config, "sign", bool, True),
             gpg_key_id=_optional(config, "gpg_key_id", str, None),
@@ -166,22 +168,21 @@ class PPAConfiguration(UploadTargetConfiguration):
             force=_optional(config, "force", bool, False),
         )
 
-    def check_validity(self):
-        if self.sign and self.gpg_key_id is None and self.gpg_signing_key is None:
+    def check_validity(self) -> None:
+        if self.sign and self.gpg_key_id is None:
             raise DebutizerYAMLError(
-                "When package signing is enabled, either the gpg_key_id field or "
-                "DEBUTIZER_GPG_SIGNING_KEY environment variable must be set"
+                "When package signing is enabled, the gpg_key_id field must be set"
             )
 
 
-class PackageSource(_ConfigurationSection):
+class PackageSourceConfiguration(_ConfigurationSection):
     def __init__(self, entry: str, gpg_key_url: Optional[str] = None):
         self.entry = entry
         self.gpg_key_url = gpg_key_url
 
     @staticmethod
-    def from_dict(config: Dict[str, Any]) -> "PackageSource":
-        return PackageSource(
+    def from_dict(config: Dict[str, Any]) -> "PackageSourceConfiguration":
+        return PackageSourceConfiguration(
             entry=_required(config, "entry", str),
             gpg_key_url=_optional(config, "gpg_key_url", str, None),
         )
@@ -193,10 +194,12 @@ class UpstreamConfiguration(_ConfigurationSection):
         url: str,
         components: List[str],
         is_trusted: Optional[bool] = False,
+        gpg_key_url: Optional[str] = None,
     ):
         self.url = url
         self.components = components
         self.is_trusted = is_trusted
+        self.gpg_key_url = gpg_key_url
 
     @staticmethod
     def from_dict(config: Dict[str, Any]) -> "UpstreamConfiguration":
@@ -204,6 +207,7 @@ class UpstreamConfiguration(_ConfigurationSection):
             url=_required(config, "url", str),
             components=_optional(config, "components", list, ["main"]),
             is_trusted=_optional(config, "is_trusted", bool, False),
+            gpg_key_url=_optional(config, "gpg_key_url", str, None),
         )
 
 
@@ -212,7 +216,7 @@ class Configuration:
         self,
         distributions: List[str],
         architectures: List[str],
-        package_sources: List[PackageSource],
+        package_sources: List[PackageSourceConfiguration],
         upstream: Optional[UpstreamConfiguration] = None,
         upload_target: Optional[UploadTargetConfiguration] = None,
     ):
@@ -241,7 +245,9 @@ class Configuration:
             package_sources = []
             package_source_dicts = _optional(config, "package_sources", list, [])
             for package_source_dict in package_source_dicts:
-                package_sources.append(PackageSource.from_dict(package_source_dict))
+                package_sources.append(
+                    PackageSourceConfiguration.from_dict(package_source_dict)
+                )
 
             upload_target_config = _optional(config, "upload_target", dict, None)
             if upload_target_config is not None and "type" not in upload_target_config:
@@ -254,10 +260,10 @@ class Configuration:
         upload_target: Optional[UploadTargetConfiguration]
         if upload_target_config is None:
             upload_target = None
-        elif upload_target_config["type"] == S3Configuration.TYPE:
-            upload_target = S3Configuration.from_dict(upload_target_config)
-        elif upload_target_config["type"] == PPAConfiguration.TYPE:
-            upload_target = PPAConfiguration.from_dict(upload_target_config)
+        elif upload_target_config["type"] == S3UploadTargetConfiguration.TYPE:
+            upload_target = S3UploadTargetConfiguration.from_dict(upload_target_config)
+        elif upload_target_config["type"] == PPAUploadTargetConfiguration.TYPE:
+            upload_target = PPAUploadTargetConfiguration.from_dict(upload_target_config)
         else:
             raise DebutizerYAMLError(
                 f"Unknown upload target type '{upload_target_config['type']}'"
@@ -271,7 +277,7 @@ class Configuration:
             upload_target=upload_target,
         )
 
-    def check_validity(self):
+    def check_validity(self) -> None:
         if self.upstream is not None and self.upstream.components is None:
             raise DebutizerYAMLError(
                 "If the 'upstream' field is set, that object must have a 'components' "
@@ -282,7 +288,7 @@ class Configuration:
 def _required(
     config: Dict[str, Any],
     key: str,
-    type_: Type,
+    type_: Type[_YAML_TYPES],
     error: Type[Exception] = DebutizerYAMLError,
 ) -> Any:
     try:
@@ -298,7 +304,7 @@ def _required(
 def _optional(
     config: Dict[str, Any],
     key: str,
-    type_: Type,
+    type_: Type[_YAML_TYPES],
     default: Any,
     error: Type[Exception] = DebutizerYAMLError,
 ) -> Any:
@@ -312,7 +318,9 @@ def _optional(
     return value
 
 
-def _check_type(key: str, value: Any, type_: Type, error: Type[Exception]) -> None:
+def _check_type(
+    key: str, value: Any, type_: Type[_YAML_TYPES], error: Type[Exception]
+) -> None:
     if not isinstance(value, type_):
         raise error(f"Field '{key}' is of type {type(value)}, but must be {type_}")
 
