@@ -1,3 +1,4 @@
+import typing
 from pathlib import Path
 from threading import Thread
 from wsgiref import simple_server
@@ -17,6 +18,7 @@ class LocalRepository:
         self._artifacts_dir = artifacts_dir
         self._app = flask.Flask(__name__)
 
+        @typing.no_type_check
         @self._app.route("/<path:path>")
         def static_files(path: str) -> flask.Response:
             return flask.send_from_directory(self._artifacts_dir, path)
@@ -35,10 +37,10 @@ class LocalRepository:
             daemon=True,
         )
 
-    def start(self):
+    def start(self) -> None:
         self._thread.start()
 
-    def close(self):
+    def close(self) -> None:
         self._server.shutdown()
         self._server.server_close()
         self._thread.join()
