@@ -1,6 +1,6 @@
 import subprocess
 from pathlib import Path
-from typing import Dict, List, Optional, Union, cast
+from typing import Dict, List, Optional, Union
 
 from debutizer.commands.utils import configure_gpg, import_gpg_key
 from debutizer.print_utils import print_notify
@@ -36,7 +36,7 @@ def add_release_files(
     """
     release_files = []
 
-    if sign and gpg_key_id is None and gpg_signing_key is not None:
+    if sign and gpg_signing_key is not None:
         import_gpg_key(gpg_signing_key)
 
     dirs = artifacts_dir.glob("dists/*")
