@@ -1,10 +1,9 @@
 import argparse
+import shutil
 
 from ..environment import Environment
 from ..print_utils import print_color, print_done, print_header, print_notify
 from ..registry import Registry
-from ..source_package import SourcePackage
-from ..upstreams import Upstream
 from .command import Command
 from .env_argparse import EnvArgumentParser
 from .utils import (
@@ -17,7 +16,7 @@ from .utils import (
 
 
 class SourceCommand(Command):
-    def __init__(self):
+    def __init__(self) -> None:
         super().__init__()
         self.parser = EnvArgumentParser(
             prog="debutizer source", description="Makes source packages"
@@ -31,37 +30,41 @@ class SourceCommand(Command):
         config = self.parse_config_file(args)
         registry = Registry()
 
+        if args.artifacts_dir.is_dir():
+            shutil.rmtree(args.artifacts_dir)
+        args.artifacts_dir.mkdir()
+
         for distro in config.distributions:
-            _source_packages(args=args, registry=registry, distribution=distro)
+            build_dir = make_build_dir()
+
+            env = Environment(
+                codename=distro,
+                architecture="",
+                package_root=args.package_dir,
+                build_root=build_dir,
+                artifacts_root=args.artifacts_dir,
+            )
+
+            _source_packages(registry, env)
 
         print_color("")
         print_done("Source complete!")
 
 
-def _source_packages(
-    args: argparse.Namespace, registry: Registry, distribution: str
-) -> None:
-    print_header(f"Sourcing packages for distribution {distribution}")
+def _source_packages(registry: Registry, env: Environment) -> None:
+    print_header(f"Sourcing packages for distribution {env.codename}")
 
-    Environment.codename = distribution
-
-    build_dir = make_build_dir()
-
-    Upstream.package_root = args.package_dir
-    Upstream.build_root = build_dir
-    SourcePackage.distribution = distribution
-
-    package_dirs = find_package_dirs(args.package_dir)
-    package_pys = process_package_pys(package_dirs, registry, build_dir)
+    package_dirs = find_package_dirs(env.package_root)
+    package_pys = process_package_pys(env, package_dirs, registry)
 
     for package_py in package_pys:
         print_notify(f"Sourcing {package_py.source_package.name}")
 
-        results_dir = make_source_files(build_dir, package_py.source_package)
+        results_dir = make_source_files(env.build_root, package_py.source_package)
 
         copy_source_artifacts(
             results_dir=results_dir,
-            artifacts_dir=args.artifacts_dir,
-            distribution=distribution,
+            artifacts_dir=env.artifacts_root,
+            distribution=env.codename,
             component=package_py.component,
         )
