@@ -9,7 +9,7 @@ from ..artifacts import (
     find_changes_files,
     find_debian_source_files,
 )
-from ..config_file import PPAConfiguration
+from ..config_file import PPAUploadTargetConfiguration
 from ..utils import configure_gpg, import_gpg_key
 from .abstract import UploadTarget
 
@@ -17,11 +17,11 @@ from .abstract import UploadTarget
 class PPAUploadTarget(UploadTarget):
     """Uploads source packages to a PPA"""
 
-    def __init__(self, ppa_config: PPAConfiguration):
+    def __init__(self, ppa_config: PPAUploadTargetConfiguration):
         self._config = ppa_config
 
     def upload(self, artifacts_dir: Path) -> None:
-        if self._config.gpg_key_id is None and self._config.gpg_signing_key is not None:
+        if self._config.gpg_signing_key is not None:
             import_gpg_key(self._config.gpg_signing_key)
 
         changes_files = find_changes_files(artifacts_dir, recursive=True)
