@@ -7,13 +7,13 @@ from datetime import datetime, timezone
 from email.utils import format_datetime
 from pathlib import Path
 from time import sleep
-from typing import Optional, cast
+from typing import Iterator, Optional, cast
 from urllib.parse import urlparse
 
 import requests
 
 from debutizer.commands.artifacts import find_artifacts
-from debutizer.commands.config_file import S3Configuration
+from debutizer.commands.config_file import S3UploadTargetConfiguration
 from debutizer.commands.repo_metadata import (
     add_packages_files,
     add_release_files,
@@ -29,7 +29,7 @@ from debutizer.subprocess_utils import run
 class S3UploadTarget(UploadTarget):
     """Uploads source and binary packages to an S3-compatible bucket"""
 
-    def __init__(self, config: S3Configuration):
+    def __init__(self, config: S3UploadTargetConfiguration):
         self._config = config
 
     def upload(self, artifacts_dir: Path) -> None:
@@ -51,7 +51,7 @@ class S3UploadTarget(UploadTarget):
 
         artifacts = find_artifacts(artifacts_dir, recursive=True)
         for artifact_file_path in artifacts:
-            print_color(f"Uploading {artifact_file_path}...")
+            print_color(f"Uploading {artifact_file_path.relative_to(artifacts_dir)}...")
             _upload_artifact(
                 prefix=self._config.prefix,
                 bucket_endpoint=bucket_endpoint,
@@ -166,7 +166,7 @@ def _upload_artifact(
 @contextmanager
 def _mount_s3fs(
     endpoint: str, bucket: str, access_key: str, secret_key: str, mount_path: Path
-):
+) -> Iterator[None]:
     with temp_file(f"{access_key}:{secret_key}") as password_path:
         run(
             [
