@@ -8,6 +8,7 @@ from typing import Dict, Iterator, List, Optional, Set, Union
 
 from xdg.BaseDirectory import save_cache_path
 
+from ..environment import Environment
 from ..errors import CommandError, UnexpectedError
 from ..package_py import PackagePy
 from ..print_utils import print_color, print_notify
@@ -27,7 +28,7 @@ from .artifacts import (
     find_debian_source_files,
     find_source_archives,
 )
-from .config_file import PackageSource
+from .config_file import PackageSourceConfiguration
 
 
 def find_package_dirs(package_dir: Path) -> List[Path]:
@@ -44,9 +45,9 @@ def find_package_dirs(package_dir: Path) -> List[Path]:
 
 
 def process_package_pys(
+    env: Environment,
     package_dirs: List[Path],
     registry: Registry,
-    build_dir: Path,
 ) -> List[PackagePy]:
     """Runs the package.py file in each package directory, extracting the configuration
     provided by that file
@@ -56,15 +57,15 @@ def process_package_pys(
     for package_dir in package_dirs:
         print_color("")
         print_notify(f"Reading {PackagePy.FILE_NAME} file for {package_dir.name}...")
-        package_py = PackagePy(package_dir / PackagePy.FILE_NAME, build_dir)
+        package_py = PackagePy(env, package_dir / PackagePy.FILE_NAME)
         package_pys.append(package_py)
-        registry.add(package_py.source_package)
+        registry.add(env, package_py.source_package)
 
     print_color("")
 
     for package_py in package_pys:
         print_notify(f"Running pre-build hook for {package_py.source_package.name}")
-        package_py.pre_build(registry)
+        package_py.pre_build(env, registry, package_py.source_package)
         # Save any further changes to the disk
         package_py.source_package.save()
 
@@ -92,8 +93,11 @@ def _order_package_pys(package_pys: List[PackagePy]) -> List[PackagePy]:
                 f"paragraph in the control file"
             )
 
+        relations = (
+            package_py.source_package.control.source.all_build_depends().parsed()
+        )
         depends_names = []
-        for relation in package_py.source_package.control.source.all_build_depends():
+        for relation in relations:
             for dependency in relation:
                 depends_names.append(dependency.name)
 
@@ -221,12 +225,16 @@ def build_package(
     source_package: SourcePackage,
     build_dir: Path,
     chroot_archive_path: Path,
+    network_access: bool = False,
+    shell_on_failure: bool = False,
 ) -> Path:
     """Builds binary packages for the given source package.
 
     :param source_package: The source package object to build binary packages for
     :param build_dir: The directory to do work in
     :param chroot_archive_path: A path to the pbuilder chroot archive
+    :param network_access: If True, the build will be allowed to access the internet
+    :param shell_on_failure: If True, a shell will be started if the build fails
     :return: The directory under the build directory where the new files are placed
     """
     working_dir = source_package.directory.parent
@@ -237,39 +245,47 @@ def build_package(
 
     command: List[Union[Path, str]] = ["pbuilder", "build"]
 
-    hook_dir = Path(__file__).parent / "pbuilder_hooks"
-    if not hook_dir.is_dir():
+    if not _HOOK_SOURCE_DIR.is_dir():
         raise UnexpectedError(
-            f"The pbuilder hook dir does not exist at {hook_dir}. This suggests a "
-            f"broken installation of Debutizer."
+            f"The pbuilder hook dir does not exist at {_HOOK_SOURCE_DIR}. This "
+            f"suggests a broken installation of Debutizer."
         )
 
-    command += [
-        "--hookdir",
-        Path(__file__).parent / "pbuilder_hooks",
-        "--buildresult",
-        results_dir,
-        "--basetgz",
-        chroot_archive_path,
-        dsc_file,
-    ]
+    with tempfile.TemporaryDirectory() as hook_dir:
+        # Copy the package list updating hook
+        shutil.copy2(str(_HOOK_SOURCE_DIR / "D70results"), str(hook_dir))
 
-    try:
-        run(
-            command,
-            on_failure="Failed to build the package",
-            cwd=working_dir,
-            root=True,
-        )
-    finally:
-        if "SUDO_USER" in os.environ:
-            # If Debutizer is being run with sudo, give the regular user access to
-            # the results dir
+        if shell_on_failure:
+            shutil.copy2(str(_HOOK_SOURCE_DIR / "C10shell"), str(hook_dir))
+
+        command += [
+            "--use-network",
+            "yes" if network_access else "no",
+            "--hookdir",
+            str(hook_dir),
+            "--buildresult",
+            results_dir,
+            "--basetgz",
+            chroot_archive_path,
+            dsc_file,
+        ]
+
+        try:
             run(
-                ["chown", "--recursive", os.environ["SUDO_USER"], results_dir],
-                on_failure="Failed to fix permissions for the build path",
+                command,
+                on_failure="Failed to build the package",
+                cwd=working_dir,
                 root=True,
             )
+        finally:
+            if "SUDO_USER" in os.environ:
+                # If Debutizer is being run with sudo, give the regular user access to
+                # the results dir
+                run(
+                    ["chown", "--recursive", os.environ["SUDO_USER"], results_dir],
+                    on_failure="Failed to fix permissions for the build path",
+                    root=True,
+                )
 
     return results_dir
 
@@ -310,7 +326,7 @@ def make_chroot(distribution: str) -> Path:
 
 
 def set_chroot_package_sources(
-    distribution: str, package_sources: List[PackageSource]
+    distribution: str, package_sources: List[PackageSourceConfiguration]
 ) -> None:
     """Sets additional package sources for the chroot corresponding to the given
     distribution
@@ -318,8 +334,9 @@ def set_chroot_package_sources(
     print_notify(f"Adding APT lists to the '{distribution}' chroot:")
     apt_list = Path("/etc/apt/sources.list.d/debutizer.list")
 
-    script = "#!/bin/sh\n"
+    script = "#!/bin/bash\n"
     script += "set -o errexit\n"
+    script += "set -o pipefail\n"
     script += "apt-get install -y gnupg curl ca-certificates\n"
     script += "update-ca-certificates\n"
 
@@ -417,7 +434,7 @@ def copy_binary_artifacts(
     distribution: str,
     component: str,
     architecture: str,
-):
+) -> None:
     """Copies binary package files to their proper location in the artifacts directory.
 
     :param results_dir: The path where the binary package files are
@@ -547,3 +564,6 @@ def _chroot_tgz_path(distribution: str) -> Path:
     )
     pbuilder_cache_path = Path(pbuilder_cache_str)
     return pbuilder_cache_path / f"debutizer-{distribution}.tgz"
+
+
+_HOOK_SOURCE_DIR = Path(__file__).parent / "pbuilder_hooks"
