@@ -2,7 +2,7 @@ import os
 import shlex
 import subprocess
 from pathlib import Path
-from typing import List, Union
+from typing import Any, List, Union
 
 from .errors import CommandError, UnexpectedError
 from .print_utils import Format, print_color
@@ -13,8 +13,8 @@ def run(
     *,
     on_failure: str,
     root: bool = False,
-    **kwargs,
-) -> subprocess.CompletedProcess:
+    **kwargs: Any,
+) -> "subprocess.CompletedProcess[str]":
     for i, arg in enumerate(command):
         if not isinstance(arg, (str, Path)):
             raise UnexpectedError(
@@ -25,7 +25,7 @@ def run(
     if root and os.geteuid() != 0:
         if os.environ.get("DEBUTIZER_ACQUIRE_ROOT"):
             # Use a command (probably sudo) to get root permissions
-            root_command_str = os.environ.get("DEBUTIZER_ROOT_COMMAND", "sudo -E")
+            root_command_str = os.environ.get("DEBUTIZER_ROOT_COMMAND", "sudo")
             root_command = shlex.split(root_command_str)
             command_no_path = root_command + command_no_path
         else:
