@@ -1,5 +1,5 @@
 from .base import Upstream
+from .git import GitUpstream
 from .local import LocalUpstream
 from .null import NullUpstream
 from .source_package import SourcePackageUpstream
-from .source_repository import SourceRepositoryUpstream
