@@ -13,7 +13,7 @@ class Version:
         upstream_version: str,
         debian_revision: Optional[str],
         full_version: str,
-    ):
+    ) -> None:
         self.epoch = epoch
         self.upstream_version = upstream_version
         self.debian_revision = debian_revision
@@ -42,7 +42,7 @@ class Version:
             full_version=version,
         )
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         return (
             f"Version("
             f"epoch={self.epoch}, "
@@ -60,7 +60,8 @@ class Version:
             return NotImplemented
 
         return (
-            self.epoch == other.epoch
+            isinstance(other, Version)
+            and self.epoch == other.epoch
             and self.upstream_version == other.upstream_version
             and self.debian_revision == other.debian_revision
             and self.full_version == other.full_version
